@@ -6,6 +6,7 @@ OC.L10N.register(
     "Error" : "Virhe",
     "New note" : "Uusi muistiinpano",
     "Distraction-free notes and writing" : "Häiriötöntä muistiinpanojen ottamista ja kirjoittamista",
+    "Please see Nextcloud server log for details." : "Katso lisätietoja Nextcloud-palvelimen lokista.",
     "Deleted {title}" : "Poistettu {title}",
     "Undo Delete" : "Kumoa poistaminen",
     "Note recovered" : "Muistiinpano palautettu",
@@ -16,6 +17,8 @@ OC.L10N.register(
     "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
     "path to notes" : "polku muistiinpanoihin",
     "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
+    "Open in edit mode" : "Avaa muokkaustilassa",
+    "Open in preview mode" : "Avaa esikatselutilassa",
     "No notes yet" : "Ei muistiinpanoja",
     "All notes" : "Kaikki muistiinpanot",
     "Categories" : "Luokat",
@@ -32,6 +35,8 @@ OC.L10N.register(
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
     "Error during preparing note for deletion." : "Virhe valmisteltaessa muistiinpanon poistamista.",
+    "Use version from server" : "Käytä versiota palvelimelta",
+    "Use current version" : "Käytä nykyistä versiota",
     "Empty note" : "Tyhjä muistiinpano",
     "Write …" : "Kirjoita…",
     "Details" : "Tiedot",
