@@ -1,17 +1,16 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "Ekki hægt að lesa síðast skoðaða minnispunktinn.",
-    "The notes folder is not accessible: %s" : "Mappa undir minnispunkta er ekki aðgengileg: %s",
+    "Notes" : "Minnispunktar",
     "Error" : "Villa",
     "New note" : "Nýr minnispunktur",
-    "Notes" : "Minnispunktar",
     "Distraction-free notes and writing" : "Augljós ritun og skoðun minnispunkta",
-    "Settings" : "Stillingar",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Það eru óvistaðir minnispunktar. Ef farið er af síðunni munu allar breytingar tapast!",
+    "Settings" : "Stillingar",
     "Folder to store your notes" : "Mappa til að geyma minnispunktana þína",
     "path to notes" : "slóð að minnispunktum",
     "File extension for new notes" : "Skráarending fyrir nýja minnispunkta",
+    "No notes yet" : "Engir minnispunktar ennþá",
     "All notes" : "Allir minnispunktar",
     "Categories" : "Flokkar",
     "Loading …" : "Hleð inn …",
@@ -24,8 +23,8 @@ OC.L10N.register(
     "Remove from favorites" : "Fjarlægja úr eftirlætum",
     "Add to favorites" : "Bæta í eftirlæti",
     "Details" : "Details",
-    "Preview" : "Forskoðun",
     "Edit" : "Breyta",
+    "Preview" : "Forskoðun",
     "Category" : "Flokkur",
     "Uncategorized" : "Óflokkað",
     "Saving failed!" : "Vistun mistókst!",
