@@ -17,6 +17,9 @@ OC.L10N.register(
     "Folder to store your notes" : "Mapp för att spara dina anteckningar",
     "path to notes" : "sökväg till anteckningar",
     "File extension for new notes" : "Filtillägg för nya anteckningar",
+    "Display mode for notes" : "Visningsläge för anteckningar",
+    "Open in edit mode" : "Öppna i redigeringsläge",
+    "Open in preview mode" : "Öppna i granskningsläge",
     "No notes yet" : "Inga anteckningar än",
     "All notes" : "Alla anteckningar",
     "Categories" : "Kategorier",
@@ -33,6 +36,7 @@ OC.L10N.register(
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till som favorit",
     "Error during preparing note for deletion." : "Fel vid förberedelse av anteckning för radering.",
+    "The note has been changed in another session. Please choose which version should be saved." : "Anteckningen har modifierats i en annan session. Vänligen välj vilken version som skall sparas.",
     "Use version from server" : "Använd version från servern",
     "Use current version" : "Använd nuvarande version",
     "Empty note" : "Tom anteckning",
